@@ -676,8 +676,7 @@ quick_button_new (const char     *icon_path,
 	button->text = (text != NULL) ? g_strdup (text) : NULL;
 	button->icon_theme = g_object_ref (icon_theme);
 
-	if (icon_path != NULL)
-		button_load_pixbuf (button, icon_path, size);
+	button_load_pixbuf (button, icon_path, size);
 
 	gtk_drag_source_set (GTK_WIDGET (button),
                              GDK_BUTTON1_MASK,
